@@ -2,8 +2,8 @@ using System;
 using System.Reflection;
 using System.Runtime.CompilerServices;
 
-[assembly: ApplicationVersion ("2.6.0", "2.6")]
-[assembly: ApplicationBuildInformation ("git-checkout", "linux-gnu", "x86_64", "2012-09-29 16:59:18 CEST")]
+[assembly: ApplicationVersion ("2.6.1", "2.6.1")]
+[assembly: ApplicationBuildInformation ("git-checkout", "linux-gnu", "x86_64", "2013-04-16 21:04:45 BST")]
 
 [assembly: AssemblyVersion ("2.6.0.0")]
 [assembly: AssemblyTitle ("Banshee")]
